==> wine-development_4.6.orig.tar.xz: wine-4.6/include/mferror.h <==
/*
 * Copyright (C) 2014 Sebastian Lackner
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef __WINE_MFERROR_H
#define __WINE_MFERROR_H

#define FACILITY_MF 0xd

#define MF_E_PLATFORM_NOT_INITIALIZED                 _HRESULT_TYPEDEF_(0xc00d36b0)
#define MF_E_BUFFERTOOSMALL                           _HRESULT_TYPEDEF_(0xc00d36b1)
#define MF_E_INVALIDREQUEST                           _HRESULT_TYPEDEF_(0xc00d36b2)
#define MF_E_INVALIDSTREAMNUMBER                      _HRESULT_TYPEDEF_(0xc00d36b3)
#define MF_E_INVALIDMEDIATYPE                         _HRESULT_TYPEDEF_(0xc00d36b4)
#define MF_E_NOTACCEPTING                             _HRESULT_TYPEDEF_(0xc00d36b5)
#define MF_E_NOT_INITIALIZED                          _HRESULT_TYPEDEF_(0xc00d36b6)
#define MF_E_UNSUPPORTED_REPRESENTATION               _HRESULT_TYPEDEF_(0xc00d36b7)
#define MF_E_NO_MORE_TYPES                            _HRESULT_TYPEDEF_(0xc00d36b9)
#define MF_E_UNSUPPORTED_SERVICE                      _HRESULT_TYPEDEF_(0xc00d36ba)
#define MF_E_UNEXPECTED                               _HRESULT_TYPEDEF_(0xc00d36bb)
#define MF_E_INVALIDNAME                              _HRESULT_TYPEDEF_(0xc00d36bc)
#define MF_E_INVALIDTYPE                              _HRESULT_TYPEDEF_(0xc00d36bd)
#define MF_E_INVALID_FILE_FORMAT                      _HRESULT_TYPEDEF_(0xc00d36be)
#define MF_E_INVALIDINDEX                             _HRESULT_TYPEDEF_(0xc00d36bf)
#define MF_E_INVALID_TIMESTAMP                        _HRESULT_TYPEDEF_(0xc00d36c0)
#define MF_E_UNSUPPORTED_SCHEME                       _HRESULT_TYPEDEF_(0xc00d36c3)
#define MF_E_UNSUPPORTED_BYTESTREAM_TYPE              _HRESULT_TYPEDEF_(0xc00d36c4)
#define MF_E_UNSUPPORTED_TIME_FORMAT                  _HRESULT_TYPEDEF_(0xc00d36c5)
#define MF_E_NO_SAMPLE_TIMESTAMP                      _HRESULT_TYPEDEF_(0xc00d36c8)
#define MF_E_NO_SAMPLE_DURATION                       _HRESULT_TYPEDEF_(0xc00d36c9)
#define MF_E_INVALID_STREAM_DATA                      _HRESULT_TYPEDEF_(0xc00d36cb)
#define MF_E_RT_UNAVAILABLE                           _HRESULT_TYPEDEF_(0xc00d36cf)
#define MF_E_UNSUPPORTED_RATE                         _HRESULT_TYPEDEF_(0xc00d36d0)
#define MF_E_THINNING_UNSUPPORTED                     _HRESULT_TYPEDEF_(0xc00d36d1)
#define MF_E_REVERSE_UNSUPPORTED                      _HRESULT_TYPEDEF_(0xc00d36d2)
#define MF_E_UNSUPPORTED_RATE_TRANSITION              _HRESULT_TYPEDEF_(0xc00d36d3)
#define MF_E_RATE_CHANGE_PREEMPTED                    _HRESULT_TYPEDEF_(0xc00d36d4)
#define MF_E_NOT_FOUND                                _HRESULT_TYPEDEF_(0xc00d36d5)
#define MF_E_NOT_AVAILABLE                            _HRESULT_TYPEDEF_(0xc00d36d6)
#define MF_E_NO_CLOCK                                 _HRESULT_TYPEDEF_(0xc00d36d7)
#define MF_S_MULTIPLE_BEGIN                           _HRESULT_TYPEDEF_(0x000d36d8)
#define MF_E_MULTIPLE_BEGIN                           _HRESULT_TYPEDEF_(0xc00d36d9)
#define MF_E_MULTIPLE_SUBSCRIBERS                     _HRESULT_TYPEDEF_(0xc00d36da)
#define MF_E_TIMER_ORPHANED                           _HRESULT_TYPEDEF_(0xc00d36db)
#define MF_E_STATE_TRANSITION_PENDING                 _HRESULT_TYPEDEF_(0xc00d36dc)
#define MF_E_UNSUPPORTED_STATE_TRANSITION             _HRESULT_TYPEDEF_(0xc00d36dd)
#define MF_E_UNRECOVERABLE_ERROR_OCCURRED             _HRESULT_TYPEDEF_(0xc00d36de)
#define MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS              _HRESULT_TYPEDEF_(0xc00d36df)
#define MF_E_SAMPLE_NOT_WRITABLE                      _HRESULT_TYPEDEF_(0xc00d36e0)
#define MF_E_INVALID_KEY                              _HRESULT_TYPEDEF_(0xc00d36e2)
#define MF_E_BAD_STARTUP_VERSION                      _HRESULT_TYPEDEF_(0xc00d36e3)
#define MF_E_UNSUPPORTED_CAPTION                      _HRESULT_TYPEDEF_(0xc00d36e4)
#define MF_E_INVALID_POSITION                         _HRESULT_TYPEDEF_(0xc00d36e5)
#define MF_E_ATTRIBUTENOTFOUND                        _HRESULT_TYPEDEF_(0xc00d36e6)
#define MF_E_PROPERTY_TYPE_NOT_ALLOWED                _HRESULT_TYPEDEF_(0xc00d36e7)
#define MF_E_PROPERTY_TYPE_NOT_SUPPORTED              _HRESULT_TYPEDEF_(0xc00d36e8)
#define MF_E_PROPERTY_EMPTY                           _HRESULT_TYPEDEF_(0xc00d36e9)
#define MF_E_PROPERTY_NOT_EMPTY                       _HRESULT_TYPEDEF_(0xc00d36ea)
#define MF_E_PROPERTY_VECTOR_NOT_ALLOWED              _HRESULT_TYPEDEF_(0xc00d36eb)
#define MF_E_PROPERTY_VECTOR_REQUIRED                 _HRESULT_TYPEDEF_(0xc00d36ec)
#define MF_E_OPERATION_CANCELLED                      _HRESULT_TYPEDEF_(0xc00d36ed)
#define MF_E_BYTESTREAM_NOT_SEEKABLE                  _HRESULT_TYPEDEF_(0xc00d36ee)
#define MF_E_DISABLED_IN_SAFEMODE                     _HRESULT_TYPEDEF_(0xc00d36ef)
#define MF_E_CANNOT_PARSE_BYTESTREAM                  _HRESULT_TYPEDEF_(0xc00d36f0)
#define MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS  _HRESULT_TYPEDEF_(0xc00d36f1)
#define MF_E_BYTESTREAM_UNKNOWN_LENGTH                _HRESULT_TYPEDEF_(0xc00d36fb)
#define MF_E_INVALID_WORKQUEUE                        _HRESULT_TYPEDEF_(0xc00d36ff)
#define MF_E_NO_EVENTS_AVAILABLE                      _HRESULT_TYPEDEF_(0xc00d3e80)
#define MF_E_INVALID_STATE_TRANSITION                 _HRESULT_TYPEDEF_(0xc00d3e82)
#define MF_E_END_OF_STREAM                            _HRESULT_TYPEDEF_(0xc00d3e84)
#define MF_E_SHUTDOWN                                 _HRESULT_TYPEDEF_(0xc00d3e85)
#define MF_E_NO_DURATION                              _HRESULT_TYPEDEF_(0xc00d3e8a)
#define MF_E_INVALID_FORMAT                           _HRESULT_TYPEDEF_(0xc00d3e8c)
#define MF_E_PROPERTY_NOT_FOUND                       _HRESULT_TYPEDEF_(0xc00d3e8d)
#define MF_E_PROPERTY_READ_ONLY                       _HRESULT_TYPEDEF_(0xc00d3e8e)
#define MF_E_PROPERTY_NOT_ALLOWED                     _HRESULT_TYPEDEF_(0xc00d3e8f)
#define MF_E_MEDIA_SOURCE_NOT_STARTED                 _HRESULT_TYPEDEF_(0xc00d3e91)
#define MF_E_UNSUPPORTED_FORMAT                       _HRESULT_TYPEDEF_(0xc00d3e98)
#define MF_E_MEDIA_SOURCE_WRONGSTATE                  _HRESULT_TYPEDEF_(0xc00d3e9b)
#define MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED         _HRESULT_TYPEDEF_(0xc00d3e9c)
#define MF_E_UNSUPPORTED_CHARACTERISTICS              _HRESULT_TYPEDEF_(0xc00d3e9e)

#define MF_E_TOPO_INVALID_OPTIONAL_NODE               _HRESULT_TYPEDEF_(0xc00d520e)
#define MF_E_TOPO_CANNOT_FIND_DECRYPTOR               _HRESULT_TYPEDEF_(0xc00d5211)
#define MF_E_TOPO_CODEC_NOT_FOUND                     _HRESULT_TYPEDEF_(0xc00d5212)
#define MF_E_TOPO_CANNOT_CONNECT                      _HRESULT_TYPEDEF_(0xc00d5213)
#define MF_E_TOPO_UNSUPPORTED                         _HRESULT_TYPEDEF_(0xc00d5214)
#define MF_E_TOPO_INVALID_TIME_ATTRIBUTES             _HRESULT_TYPEDEF_(0xc00d5215)
#define MF_E_TOPO_LOOPS_IN_TOPOLOGY                   _HRESULT_TYPEDEF_(0xC00d5216)
#define MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR     _HRESULT_TYPEDEF_(0xc00d5217)
#define MF_E_TOPO_MISSING_STREAM_DESCRIPTOR           _HRESULT_TYPEDEF_(0xc00d5218)
#define MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED      _HRESULT_TYPEDEF_(0xc00d5219)
#define MF_E_TOPO_MISSING_SOURCE                      _HRESULT_TYPEDEF_(0xc00d521a)
#define MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED          _HRESULT_TYPEDEF_(0xc00d521b)

#define MF_E_CLOCK_NO_TIME_SOURCE                     _HRESULT_TYPEDEF_(0xc00d9c41)
#define MF_E_CLOCK_STATE_ALREADY_SET                  _HRESULT_TYPEDEF_(0xc00d9c42)

#endif  /* __WINE_MFERROR_H */

==> wine-development_4.9.orig.tar.xz: wine-4.9/include/mferror.h <==
/*
 * Copyright (C) 2014 Sebastian Lackner
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef __WINE_MFERROR_H
#define __WINE_MFERROR_H

#define FACILITY_MF 0xd

#define MF_E_PLATFORM_NOT_INITIALIZED                 _HRESULT_TYPEDEF_(0xc00d36b0)
#define MF_E_BUFFERTOOSMALL                           _HRESULT_TYPEDEF_(0xc00d36b1)
#define MF_E_INVALIDREQUEST                           _HRESULT_TYPEDEF_(0xc00d36b2)
#define MF_E_INVALIDSTREAMNUMBER                      _HRESULT_TYPEDEF_(0xc00d36b3)
#define MF_E_INVALIDMEDIATYPE                         _HRESULT_TYPEDEF_(0xc00d36b4)
#define MF_E_NOTACCEPTING                             _HRESULT_TYPEDEF_(0xc00d36b5)
#define MF_E_NOT_INITIALIZED                          _HRESULT_TYPEDEF_(0xc00d36b6)
#define MF_E_UNSUPPORTED_REPRESENTATION               _HRESULT_TYPEDEF_(0xc00d36b7)
#define MF_E_NO_MORE_TYPES                            _HRESULT_TYPEDEF_(0xc00d36b9)
#define MF_E_UNSUPPORTED_SERVICE                      _HRESULT_TYPEDEF_(0xc00d36ba)
#define MF_E_UNEXPECTED                               _HRESULT_TYPEDEF_(0xc00d36bb)
#define MF_E_INVALIDNAME                              _HRESULT_TYPEDEF_(0xc00d36bc)
#define MF_E_INVALIDTYPE                              _HRESULT_TYPEDEF_(0xc00d36bd)
#define MF_E_INVALID_FILE_FORMAT                      _HRESULT_TYPEDEF_(0xc00d36be)
#define MF_E_INVALIDINDEX                             _HRESULT_TYPEDEF_(0xc00d36bf)
#define MF_E_INVALID_TIMESTAMP                        _HRESULT_TYPEDEF_(0xc00d36c0)
#define MF_E_UNSUPPORTED_SCHEME                       _HRESULT_TYPEDEF_(0xc00d36c3)
#define MF_E_UNSUPPORTED_BYTESTREAM_TYPE              _HRESULT_TYPEDEF_(0xc00d36c4)
#define MF_E_UNSUPPORTED_TIME_FORMAT                  _HRESULT_TYPEDEF_(0xc00d36c5)
#define MF_E_NO_SAMPLE_TIMESTAMP                      _HRESULT_TYPEDEF_(0xc00d36c8)
#define MF_E_NO_SAMPLE_DURATION                       _HRESULT_TYPEDEF_(0xc00d36c9)
#define MF_E_INVALID_STREAM_DATA                      _HRESULT_TYPEDEF_(0xc00d36cb)
#define MF_E_RT_UNAVAILABLE                           _HRESULT_TYPEDEF_(0xc00d36cf)
#define MF_E_UNSUPPORTED_RATE                         _HRESULT_TYPEDEF_(0xc00d36d0)
#define MF_E_THINNING_UNSUPPORTED                     _HRESULT_TYPEDEF_(0xc00d36d1)
#define MF_E_REVERSE_UNSUPPORTED                      _HRESULT_TYPEDEF_(0xc00d36d2)
#define MF_E_UNSUPPORTED_RATE_TRANSITION              _HRESULT_TYPEDEF_(0xc00d36d3)
#define MF_E_RATE_CHANGE_PREEMPTED                    _HRESULT_TYPEDEF_(0xc00d36d4)
#define MF_E_NOT_FOUND                                _HRESULT_TYPEDEF_(0xc00d36d5)
#define MF_E_NOT_AVAILABLE                            _HRESULT_TYPEDEF_(0xc00d36d6)
#define MF_E_NO_CLOCK                                 _HRESULT_TYPEDEF_(0xc00d36d7)
#define MF_S_MULTIPLE_BEGIN                           _HRESULT_TYPEDEF_(0x000d36d8)
#define MF_E_MULTIPLE_BEGIN                           _HRESULT_TYPEDEF_(0xc00d36d9)
#define MF_E_MULTIPLE_SUBSCRIBERS                     _HRESULT_TYPEDEF_(0xc00d36da)
#define MF_E_TIMER_ORPHANED                           _HRESULT_TYPEDEF_(0xc00d36db)
#define MF_E_STATE_TRANSITION_PENDING                 _HRESULT_TYPEDEF_(0xc00d36dc)
#define MF_E_UNSUPPORTED_STATE_TRANSITION             _HRESULT_TYPEDEF_(0xc00d36dd)
#define MF_E_UNRECOVERABLE_ERROR_OCCURRED             _HRESULT_TYPEDEF_(0xc00d36de)
#define MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS              _HRESULT_TYPEDEF_(0xc00d36df)
#define MF_E_SAMPLE_NOT_WRITABLE                      _HRESULT_TYPEDEF_(0xc00d36e0)
#define MF_E_INVALID_KEY                              _HRESULT_TYPEDEF_(0xc00d36e2)
#define MF_E_BAD_STARTUP_VERSION                      _HRESULT_TYPEDEF_(0xc00d36e3)
#define MF_E_UNSUPPORTED_CAPTION                      _HRESULT_TYPEDEF_(0xc00d36e4)
#define MF_E_INVALID_POSITION                         _HRESULT_TYPEDEF_(0xc00d36e5)
#define MF_E_ATTRIBUTENOTFOUND                        _HRESULT_TYPEDEF_(0xc00d36e6)
#define MF_E_PROPERTY_TYPE_NOT_ALLOWED                _HRESULT_TYPEDEF_(0xc00d36e7)
#define MF_E_PROPERTY_TYPE_NOT_SUPPORTED              _HRESULT_TYPEDEF_(0xc00d36e8)
#define MF_E_PROPERTY_EMPTY                           _HRESULT_TYPEDEF_(0xc00d36e9)
#define MF_E_PROPERTY_NOT_EMPTY                       _HRESULT_TYPEDEF_(0xc00d36ea)
#define MF_E_PROPERTY_VECTOR_NOT_ALLOWED              _HRESULT_TYPEDEF_(0xc00d36eb)
#define MF_E_PROPERTY_VECTOR_REQUIRED                 _HRESULT_TYPEDEF_(0xc00d36ec)
#define MF_E_OPERATION_CANCELLED                      _HRESULT_TYPEDEF_(0xc00d36ed)
#define MF_E_BYTESTREAM_NOT_SEEKABLE                  _HRESULT_TYPEDEF_(0xc00d36ee)
#define MF_E_DISABLED_IN_SAFEMODE                     _HRESULT_TYPEDEF_(0xc00d36ef)
#define MF_E_CANNOT_PARSE_BYTESTREAM                  _HRESULT_TYPEDEF_(0xc00d36f0)
#define MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS  _HRESULT_TYPEDEF_(0xc00d36f1)
#define MF_E_BYTESTREAM_UNKNOWN_LENGTH                _HRESULT_TYPEDEF_(0xc00d36fb)
#define MF_E_INVALID_WORKQUEUE                        _HRESULT_TYPEDEF_(0xc00d36ff)
#define MF_E_NO_EVENTS_AVAILABLE                      _HRESULT_TYPEDEF_(0xc00d3e80)
#define MF_E_INVALID_STATE_TRANSITION                 _HRESULT_TYPEDEF_(0xc00d3e82)
#define MF_E_END_OF_STREAM                            _HRESULT_TYPEDEF_(0xc00d3e84)
#define MF_E_SHUTDOWN                                 _HRESULT_TYPEDEF_(0xc00d3e85)
#define MF_E_NO_DURATION                              _HRESULT_TYPEDEF_(0xc00d3e8a)
#define MF_E_INVALID_FORMAT                           _HRESULT_TYPEDEF_(0xc00d3e8c)
#define MF_E_PROPERTY_NOT_FOUND                       _HRESULT_TYPEDEF_(0xc00d3e8d)
#define MF_E_PROPERTY_READ_ONLY                       _HRESULT_TYPEDEF_(0xc00d3e8e)
#define MF_E_PROPERTY_NOT_ALLOWED                     _HRESULT_TYPEDEF_(0xc00d3e8f)
#define MF_E_MEDIA_SOURCE_NOT_STARTED                 _HRESULT_TYPEDEF_(0xc00d3e91)
#define MF_E_UNSUPPORTED_FORMAT                       _HRESULT_TYPEDEF_(0xc00d3e98)
#define MF_E_MEDIA_SOURCE_WRONGSTATE                  _HRESULT_TYPEDEF_(0xc00d3e9b)
#define MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED         _HRESULT_TYPEDEF_(0xc00d3e9c)
#define MF_E_UNSUPPORTED_CHARACTERISTICS              _HRESULT_TYPEDEF_(0xc00d3e9e)

#define MF_E_STREAMSINK_REMOVED                       _HRESULT_TYPEDEF_(0xc00d4a38)
#define MF_E_STREAMSINKS_OUT_OF_SYNC                  _HRESULT_TYPEDEF_(0xc00d4a3a)
#define MF_E_STREAMSINKS_FIXED                        _HRESULT_TYPEDEF_(0xc00d4a3b)
#define MF_E_STREAMSINK_EXISTS                        _HRESULT_TYPEDEF_(0xc00d4a3c)
#define MF_E_SAMPLEALLOCATOR_CANCELED                 _HRESULT_TYPEDEF_(0xc00d4a3d)
#define MF_E_SAMPLEALLOCATOR_EMPTY                    _HRESULT_TYPEDEF_(0xc00d4a3e)
#define MF_E_SINK_ALREADYSTOPPED                      _HRESULT_TYPEDEF_(0xc00d4a3f)
#define MF_E_ASF_FILESINK_BITRATE_UNKNOWN             _HRESULT_TYPEDEF_(0xc00d4a40)
#define MF_E_SINK_NO_STREAMS                          _HRESULT_TYPEDEF_(0xc00d4a41)
#define MF_S_SINK_NOT_FINALIZED                       _HRESULT_TYPEDEF_(0x000d4a42)
#define MF_E_METADATA_TOO_LONG                        _HRESULT_TYPEDEF_(0xc00d4a43)
#define MF_E_SINK_NO_SAMPLES_PROCESSED                _HRESULT_TYPEDEF_(0xc00d4a44)
#define MF_E_SINK_HEADERS_NOT_FOUND                   _HRESULT_TYPEDEF_(0xc00d4a45)

#define MF_E_TOPO_INVALID_OPTIONAL_NODE               _HRESULT_TYPEDEF_(0xc00d520e)
#define MF_E_TOPO_CANNOT_FIND_DECRYPTOR               _HRESULT_TYPEDEF_(0xc00d5211)
#define MF_E_TOPO_CODEC_NOT_FOUND                     _HRESULT_TYPEDEF_(0xc00d5212)
#define MF_E_TOPO_CANNOT_CONNECT                      _HRESULT_TYPEDEF_(0xc00d5213)
#define MF_E_TOPO_UNSUPPORTED                         _HRESULT_TYPEDEF_(0xc00d5214)
#define MF_E_TOPO_INVALID_TIME_ATTRIBUTES             _HRESULT_TYPEDEF_(0xc00d5215)
#define MF_E_TOPO_LOOPS_IN_TOPOLOGY                   _HRESULT_TYPEDEF_(0xC00d5216)
#define MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR     _HRESULT_TYPEDEF_(0xc00d5217)
#define MF_E_TOPO_MISSING_STREAM_DESCRIPTOR           _HRESULT_TYPEDEF_(0xc00d5218)
#define MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED      _HRESULT_TYPEDEF_(0xc00d5219)
#define MF_E_TOPO_MISSING_SOURCE                      _HRESULT_TYPEDEF_(0xc00d521a)
#define MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED          _HRESULT_TYPEDEF_(0xc00d521b)

#define MF_E_CLOCK_NO_TIME_SOURCE                     _HRESULT_TYPEDEF_(0xc00d9c41)
#define MF_E_CLOCK_STATE_ALREADY_SET                  _HRESULT_TYPEDEF_(0xc00d9c42)

#endif  /* __WINE_MFERROR_H */
